@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 2001 Ian Reinhart Geiser <geiseri@yahoo.com>
-   Copyright (C) 2006 Thiago Macieira <thiago@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2001 Ian Reinhart Geiser <geiseri@yahoo.com>
+    SPDX-FileCopyrightText: 2006 Thiago Macieira <thiago@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the Lesser GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the Lesser GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmainwindowiface_p.h"
@@ -23,14 +11,16 @@
 #include "kactioncollection.h"
 #include "kxmlguiwindow.h"
 
-#include <QApplication>
 #include <QAction>
+#include <QApplication>
 #include <QClipboard>
 
+#include <algorithm>
+
 KMainWindowInterface::KMainWindowInterface(KXmlGuiWindow *mainWindow)
     : QDBusAbstractAdaptor(mainWindow)
+    , m_MainWindow(mainWindow)
 {
-    m_MainWindow = mainWindow;
 }
 
 KMainWindowInterface::~KMainWindowInterface()
@@ -42,7 +32,11 @@ QStringList KMainWindowInterface::actions()
     QStringList tmp_actions;
     const QList<QAction *> lst = m_MainWindow->actionCollection()->actions();
     for (QAction *it : lst) {
-        if (!it->associatedWidgets().isEmpty()) {
+        const QList<QObject *> associatedObjects = it->associatedObjects();
+        const bool hasAssociatedWidgets = std::any_of(associatedObjects.cbegin(), associatedObjects.cend(), [](QObject *object) {
+            return (qobject_cast<QWidget *>(object) != nullptr);
+        });
+        if (hasAssociatedWidgets) {
             tmp_actions.append(it->objectName());
         }
     }
